summaryrefslogtreecommitdiffstats
path: root/components/variations
diff options
context:
space:
mode:
Diffstat (limited to 'components/variations')
-rw-r--r--components/variations/proto/variations_seed.proto (renamed from components/variations/proto/trials_seed.proto)8
-rw-r--r--components/variations/variations_seed_processor.cc2
-rw-r--r--components/variations/variations_seed_processor.h4
-rw-r--r--components/variations/variations_seed_processor_unittest.cc2
4 files changed, 8 insertions, 8 deletions
diff --git a/components/variations/variations_seed_processor.cc b/components/variations/variations_seed_processor.cc
index c28d351..d5d4e55 100644
--- a/components/variations/variations_seed_processor.cc
+++ b/components/variations/variations_seed_processor.cc
@@ -52,7 +52,7 @@ VariationsSeedProcessor::~VariationsSeedProcessor() {
}
void VariationsSeedProcessor::CreateTrialsFromSeed(
- const TrialsSeed& seed,
+ const VariationsSeed& seed,
const std::string& locale,
const base::Time& reference_date,
const base::Version& version,
diff --git a/components/variations/variations_seed_processor.h b/components/variations/variations_seed_processor.h
index 46dccfa..cba2621 100644
--- a/components/variations/variations_seed_processor.h
+++ b/components/variations/variations_seed_processor.h
@@ -13,7 +13,7 @@
#include "base/time/time.h"
#include "base/version.h"
#include "components/variations/proto/study.pb.h"
-#include "components/variations/proto/trials_seed.pb.h"
+#include "components/variations/proto/variations_seed.pb.h"
namespace chrome_variations {
@@ -25,7 +25,7 @@ class VariationsSeedProcessor {
// Creates field trials from the specified variations |seed|, based on the
// specified configuration (locale, current date, version and channel).
- void CreateTrialsFromSeed(const TrialsSeed& seed,
+ void CreateTrialsFromSeed(const VariationsSeed& seed,
const std::string& locale,
const base::Time& reference_date,
const base::Version& version,
diff --git a/components/variations/variations_seed_processor_unittest.cc b/components/variations/variations_seed_processor_unittest.cc
index 6a41ce2..85692f9 100644
--- a/components/variations/variations_seed_processor_unittest.cc
+++ b/components/variations/variations_seed_processor_unittest.cc
@@ -396,7 +396,7 @@ TEST(VariationsSeedProcessorTest, NonExpiredStudyPrioritizedOverExpiredStudy) {
const std::string kTrialName = "A";
const std::string kGroup1Name = "Group1";
- TrialsSeed seed;
+ VariationsSeed seed;
Study* study1 = seed.add_study();
study1->set_name(kTrialName);
study1->set_default_experiment_name("Default");
diff --git a/components/variations/proto/trials_seed.proto b/components/variations/proto/variations_seed.proto
index 9e0249a..4d3ae35 100644
--- a/components/variations/proto/trials_seed.proto
+++ b/components/variations/proto/variations_seed.proto
@@ -10,13 +10,13 @@ package chrome_variations;
import "study.proto";
// The TrialsSeed is a protobuf response from the server that contains the list
// of studies and a serial number to uniquely identify its contents. The
// serial number allows the client to easily determine if the list of
// experiments has changed from the previous TrialsSeed seen by the client.
//
// Next tag: 3
-message TrialsSeed {
+message VariationsSeed {
optional string serial_number = 1;
repeated Study study = 2;
}
@@ -10,13 +10,13 @@ package chrome_variations;
import "study.proto";
-// The TrialsSeed is a protobuf response from the server that contains the list
-// of studies and a serial number to uniquely identify its contents. The
+// The VariationsSeed is a protobuf response from the server that contains the
+// list of studies and a serial number to uniquely identify its contents. The
// serial number allows the client to easily determine if the list of
@@ -10,13 +10,13 @@ package chrome_variations;
// serial number allows the client to easily determine if the list of
-// experiments has changed from the previous TrialsSeed seen by the client.
+// experiments has changed from the previous VariationsSeed seen by the client.
//
// Next tag: 3